#
# spec file for package python-guessit
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without test
%else
%bcond_with test
%endif
Name:           python-guessit
Version:        3.8.0
Release:        5.1
Summary:        A library for guessing information from video files
License:        LGPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/wackou/guessit
Source0:        https://files.pythonhosted.org/packages/source/g/guessit/guessit-%{version}.tar.gz
# PATCH-FIX-UPSTREAM remove-six.patch
Patch0:         remove-six.patch
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module babelfish >= 0.6.0}
BuildRequires:  %{python_module importlib_resources if %python-base < 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module rebulk >= 3.2.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-babelfish >= 0.6.0
Requires:       python-python-dateutil
Requires:       python-rebulk >= 3.2.0
%if %{?python_version_nodots} < 39
Requires:       python-importlib_resources
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module pytest >= 5}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest-mock >= 3.3.1}
%endif
%python_subpackages

%description
GuessIt is a Python library that extracts as much information as
possible from a video file.
It has a filename matcher that allows to guess a lot of metadata from
a video using its filename only. This matcher works with both movies
and TV shows episodes.

%prep
%autosetup -p1 -n guessit-%{version}
# Remove shebang from non-executable files
for i in {'audio_codec','bit_rate','bonus','cd','container','country','crc','date','edition','episodes','episode_title','film','__init__','language','mimetype','other','part','release_group','screen_size','size','source','streaming_service','title','type','video_codec','website'}; do
  sed -i -e "1d" "guessit/rules/properties/$i.py"
done
for i in {'common/comparators','common/date','common/expected','common/formatters','common/__init__','common/numeral','common/pattern','common/quantity','common/validators','common/words','__init__','markers/groups','markers/__init__','markers/path','processors','properties/audio_codec','properties/bit_rate','properties/bonus','properties/cd','properties/container','properties/country','properties/crc','properties/date','properties/edition','properties/episodes','properties/episode_title','properties/film','properties/__init__','properties/language','properties/mimetype','properties/other','properties/part','properties/release_group','properties/screen_size','properties/size','properties/source','properties/streaming_service','properties/title','properties/type','properties/video_codec','properties/website'}; do
  sed -i -e "1d" "guessit/rules/$i.py"
done
for i in {'api','data/__init__','__init__','jsonutils','__main__','monkeypatch','options','reutils','test/__init__','test/rules/__init__','test/rules/processors_test','test/test_api','test/test_api_unicode_literals','test/test_benchmark','test/test_main','test/test_options','test/test_yml','__version__','yamlutils'}; do
  sed -i -e "1d" "guessit/$i.py"
done
# https://pypi.org/project/pytest-runner/
sed -i 's:.pytest-runner.::' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/guessit
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%pytest
%endif

%post
%python_install_alternative guessit

%postun
%python_uninstall_alternative guessit

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/guessit
%{python_sitelib}/guessit
%{python_sitelib}/guessit-%{version}.dist-info

%changelog
* Tue Apr  8 2025 Ben Greiner <code@bnavigator.de>
- Fix dependencies
* Fri Jan 10 2025 Nico Krapp <nico.krapp@suse.com>
- migrate to pyproject macros
- add remove-six.patch to drop dependency on python-six
* Sun Jun 23 2024 Luigi Baldoni <aloisio@gmx.com>
- Raise version requirement for python-rebulk (fixes boo#1226826)
* Fri Feb 16 2024 Luigi Baldoni <aloisio@gmx.com>
- Disable tests for Leap 15.6
* Thu Dec 14 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.8.0
  Chore:
  * migrate setup.cfg to pyproject.toml
  * remove win_private_assemblies from pyinstaller spec
  * Silence pylint
  Feature:
  * detect Dolby Vision from DV
  * add Paramount+ to Streaming Services
  * add amzn-cbr
  * add python 3.12 and pypy 3.10 support
  Fix:
  * pathlib.Path.__enter__() is deprecated
  * importlib.resources.read_text() is deprecated
  Style:
  * fix pylint false positive
* Mon Feb 20 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.7.1
  Fix:
  * episode: Ignore absolute_episode guess when SxxExx match is
    available in filepart
  + title: Fix title guessing for Show Name/Season XX/episode.mkv
    directories pattern
* Sat Feb 18 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.7.0
  Feature:
  * week: Add week property
  Fix:
  * episode: Fix invalid episode range when a weak episode is
    present before the match
  * expected: Build output from input string for
    expected_title/expected_group
  * release_group: Properly extract group name from format "Title
  * edition: Improve remastered/restored detection
  * container: Add m2ts to container extensions
  Documentation:
  * contributing: Update branch name
* Sat Feb 18 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.6.0
  Feature:
  * audio_codec: Detect "DTS:X"
* Wed Nov  2 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.5.0
  Feature:
  * dependencies: Drop Python 3.6 support
  Fix:
  * audio_codec: Detect "E-AC-3" and "AC-3"
  * typo: Fix common typo
* Fri Feb 18 2022 Antonio Larrosa <alarrosa@suse.com>
- Rename the dependency on importlib-resources to
  importlib_resources to be compatible with the SLE packages
* Sat Nov 20 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.4.3
  Fix:
  * setuptools: Drop usage of test_requires and setup_requires
* Fri Nov 19 2021 pgajdos@suse.com
- do not require pytest-runner, it is not needed
* Mon Nov  8 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.4.2
  Fix:
  * dependencies: Use babelfish>=0.6.0
* Sat Nov  6 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.4.1
  Fix:
  * other: Detect "Open Matte" with non-space separator
  * packaging: Use stdlib importlib.resources in py 3.7+
* Fri Nov  5 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.4.0
  Feature:
  * other: Add restored support and match 4k-* patterns
  * other: Add 2in1 support
  * python: Add python 3.10 support, drop python 3.5 support
  * audio_channels: Add support for "1.0" audio channels
  * streaming_service: Add more streaming services
  * other: Add ONA/OAD support
  * other: Add Repack and ReRip followed by a digit support
  Fix:
  * source: Avoid Shots to be guessed as Showtime and TS
  * screen_size: Add 540i
  * language: Fix language and subtitle_languages in some
    situations
  * packaging: Use importlib-resources instead of pkgutil
  * other: Fix Open Matte when written as is
  * frame_rate: Enhance frame_rate when ending with .000 or
    space separated
  * packaging: Use importlib-resources instead of pkg_resources
  * edition: Better support for "Criterion"
  * advanced-config: Fix removal of custom rebulk rules
  * streaming_service: Make SBS ambiguous
  * streaming_service: Keep pattern to avoid rebuilding rules
  * proper_count: Fix proper_count raw output to include all
    matches
  * website: Fix website when it contains a digit
  Documentation:
  * Add new properties
* Tue Jun  8 2021 Luigi Baldoni <aloisio@gmx.com>
- Fix requirement version
* Sat Feb  6 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.3.1
  Fix:
  * options: Fix custom options.json groups starting/ending
  Documentation:
  * Lighten README and update doc index page
* Thu Feb  4 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to verison 3.3.0
  Feature:
  * Add --output-input-string option
  * streaming_service: Add Showtime, HBO and AppleTV
  * other: Add Hybrid support
  Fix:
  * options: Avoid appending None values to list when merging
    options
  * streaming_service: Add iT keyword support for iTunes
  * streaming_service: Fix regex patterns declared with re:
    prefix
  Documentation:
  * readme: Avoid mixed-content in github pages
* Thu Dec 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.2.0
  * Add python 3.9 support, drop python 2.7 support
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Sun May  3 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.1.1
  * Drop python `3.4` support
  * Use SafeLoader with `yaml.load()`
* Tue Sep  3 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.1.0
  * Add python `3.8` support
  * Use rebulk `2.*`
  * Remove `v` from `subtitle_language` prefix in default
    configuration
  * Add `Variable Frame Rate` value to `other` property (VFR tag)
  * Use episode words defined in configuration in a rebulk rule
  * Avoid trigger of useless rules consequences
  * Fix possible crash in weak episode removal
  * Fix issue caused by `streaming_service` property conflicts
  * Fix source validation when more than one pattern match
  * Fix issue with some titles on multiple fileparts
  * Fix issue related to website exclusion inside title
* Tue Jun 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.4
  * `screen_size` property `540p` was added.
  * Fix `audio_channel` detection for `6.0`
  * Fix common words being detected as language
  * `streaming_service` is now configurable in advanced options
  * Add `DC Universe` to `streaming_service`
  * Improve detection when release name in between brackets
  * Improve language detection
  * Fix wrong 3D detection
  * Fix to keep separators for single characters. E.g.: S.W.A.T.
  * Fix `Show Name/Season SS/Ep. EE - Title`
  * Added `This is Us` to default expected titles
  * Added `suggested_expected` to the api to support apps that
    uses guessit as a library
  * Added `Extras` detection as `other` property
  * Add more streaming sites
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.3:
  * Add MP2 audio_codec value.
  * Proper and Fix have been separated in two distinct other values.
  * Add 1e18 season/episode pattern.
  * Fix false release_group matches with --expected-title option.
  * Fix parent folder ending with a digit detected as title
  * Fix wrong season/year with ``--type episode `` option. Serie(s) keyword has been removed from default configuration.
  * Fix missing property when episode_details pattern appears in title.
  * Ensure consistent behavior between CLI and Python module.
  * Removed Extras and Bonus values from episode_details property as those tags may also appear in movies
  * Add Scalable Video Coding, Advanced Video Codec High Definition and High Efficiency Video Coding values to
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Sep  7 2018 Jan Engelhardt <jengelh@inai.de>
- Trim name repetition in summary.
* Mon Sep  3 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update package test syntax to match up other python pkgs
* Sat Sep  1 2018 aloisio@gmx.com
- Update to version 3.0.0
  * Renamed `format` property to `source`.
  * `source` property `Cam` is now `Camera` or `HD Camera`
  * `source` property `Telesync` is now `Telesync` or `HD
    Telesync`
  * `source` property `PPV` is now `Pay-per-view`
  * `source` property `DVB` is now `Digital TV`
  * `source` property `VOD` is now `Video on Demand`
  * `source` property `WEBRip` is now `Web` with additional
    property `other`: `Rip`
  * `source` property `WEB-DL` is now `Web`
  * `source` property `AHDTV` is now `Analog HDTV`
  * `source` property `UHDTV` is now `Ultra HDTV`
  * `source` property `HDTC` is now `HD Telecine`
  * `screen_size` property `360i` was added.
  * `screen_size` property `480i` was added.
  * `screen_size` property `576i` was added.
  * `screen_size` property `900i` was added.
  * `screen_size` property `1440p` was added.
  * `screen_size` property `4K` is now `2160p`
  * `screen_size` property `4320p` was added.
  * `video_codec` property `h264` is now `H.264`
  * `video_codec` property `h265` is now `H.265`
  * `video_codec` property `Mpeg2` is now `MPEG-2`
  * `video_codec` property `Real` is now `RealVideo`
  * `video_codec` property `XviD` is now `Xvid`
  * `video_profile` property `BP` is now `Baseline`.
  * `video_profile` property `HP` is now `High`.
  * `video_profile` property `XP` is now `Extended`.
  * `video_profile` property `MP` is now `Main`.
  * `video_profile` property `Hi422P` is now `High 4:2:2`.
  * `video_profile` property `Hi444PP` is now `High 4:4:4
    Predictive`.
  * `video_profile` property `High 10` was added.
  * `video_profile` property `8bit` was removed. `8bit` is
    detected as `color_depth`: `8-bit`
  * `video_profile` property `10bit` was removed. `10bit` is
    detected as `color_depth`: `10-bit`
  * `audio_codec` property `DTS-HD` was added.
  * `audio_codec` property `AC3` is now `Dolby Digital`
  * `audio_codec` property `EAC3` is now `Dolby Digital Plus`
  * `audio_codec` property `TrueHD` is now `Dolby TrueHD`
  * `audio_codec` property `DolbyAtmos` is now `Dolby Atmos`.
  * `audio_profile` property `HE` is now `High Efficiency`.
  * `audio_profile` property `LC` is now `Low Complexity`.
  * `audio_profile` property `HQ` is now `High Quality`.
  * `audio_profile` property `HDMA` is now `Master Audio`.
  * `edition` property `Collector Edition` is now `Collector`
  * `edition` property `Special Edition` is now `Special`
  * `edition` property `Criterion Edition` is now `Criterion`
  * `edition` property `Deluxe Edition` is now `Deluxe`
  * `edition` property `Limited Edition` is now `Limited`
  * `edition` property `Theatrical Edition` is now `Theatrical`
  * `edition` property `Director's Definitive Cut` was added.
  * `episode_details` property `Oav` and `Ova` were removed.
    They are now `other: Original Animated Video`
  * `episode_details` property `Omake` is now `Extras`
  * `episode_details` property `Final` was added.
  * `other` property `Rip` was added.
  * `other` property `DDC` was removed. `DDC` is now `edition`:
    `Director's Definitive Cut`
  * `other` property `CC` was removed. `CC` is now `edition`:
    `Criterion`
  * `other` property `FINAL` was removed. `FINAL` is now
    `episode_details`: `Final`
  * `other` property `Original Animated Video` was added.
  * `other` property `OV` is now `Original Video`
  * `other` property `AudioFix` is now `Audio Fixed`
  * `other` property `SyncFix` is now `Sync Fixed`
  * `other` property `DualAudio` is now `Dual Audio`
  * `other` property `Fansub` is now `Fan Subtitled`
  * `other` property `Fastsub` is now `Fast Subtitled`
  * `other` property `FullHD` is now `Full HD`
  * `other` property `UltraHD` is now `Ultra HD`
  * `other` property `mHD` and `HDLight` are now `Micro HD`
  * `other` property `HQ` is now `High Quality`
  * `other` property `HR` is now `High Resolution`
  * `other` property `LD` is now `Line Dubbed`
  * `other` property `MD` is now `Mic Dubbed`
  * `other` property `Low Definition` was added.
  * `other` property `LiNE` is now `Line Audio`
  * `other` property `R5` is now `Region 5`
  * `other` property `Region C` was added.
  * `other` property `ReEncoded` is now `Reencoded`
  * `other` property `WideScreen` is now `Widescreen`
  * Added `Ultra HD Blu-ray` as new `source` possible value.
  * Added `Standard Dynamic Range` as new `other` possible value.
  * Added `HDR10` as new `other` possible value.
  * Added `Dolby Vision` as new `other` possible value.
  * Added `BT.2020` as new `other` possible value.
  * Added `12-bit` as new `color_depth` possible value.
  * Added `IMAX` as new `edition` possible value.
  * Added `Upscaled` as new `other` possible value.
  * Added `High Frame Rate` as new `other` possible value.
  * Added `Ultimate` as new `edition` possible value.
  * Added `Fan` as new `edition` possible value.
  * Added `High Resolution Audio` as new `audio_profile`
    possible value.
  * Added `Extended Surround` as new `audio_profile` possible
    value.
  * Added `EX` as new `audio_profile` possible value
  * Added `Opus` as new `audio_codec` possible value
  * Added `aspect_ratio` as new property. Also used to validate
    if a screen_size is a standard resolution.
  * Fixed unwanted language and country detection for exotic
    languages.
  * Added default and configurable list of allowed languages and
    countries
  * Added `VC-1` as new `video_codec` possible value
  * Enhanced dash-separated `release_group` detection.
  * Changed `size` output to return `guessit.Quantity` object.
  * Changed `size` output to return `guessit.Size` object.
  * Added `audio_video_rate` as new possible property.
  * Added `video_video_rate` as new possible property.
  * Added `frame_rate` as new possible property.
  * Added `disc` as a new possible property.
  * Added `H.263` as new `video_codec` possible value.
  * Added `VP7` as new `video_codec` possible value.
  * Added `VP8` as new `video_codec` possible value.
  * Added `VP9` as new `video_codec` possible value.
  * Added `Vorbis` as new `audio_codec` possible value.
  * Added `PCM` as new `audio_codec` possible value.
  * Added `LPCM` as new `audio_codec` possible value.
  * Added `Digital Master` as new `source` possible value.
  * Added several new values for `streaming_service`.
  * Added new options `--includes` and `--excludes`.
  * Added `Sample` as new `other` possible value.
  * Added `Obfuscated` as new `other` possible value.
  * Added `Proof` as new `other` possible value.
  * Added `Repost` as new `other` possible value.
  * Added advanced guessit configuration to config files.
  * Add support for `pathlib.Path` objects on guessit API input.
  version 2.1.4
  * Fix broken match function when using `rebulk>=0.9.0`.
- Enabled tests
* Tue Apr 11 2017 jengelh@inai.de
- spellcasing fixes to the description; removal of extreme words.
* Fri Apr  7 2017 dmueller@suse.com
- fix dateutil dependency again
* Wed Mar  8 2017 aloisio@gmx.com
- Converted to single-spec
- Switched source URL to pypi.io
- Dropped self-generated manpage
- Dropped python-guessit-rpmlintrc (corrected relevant files)
* Thu Dec 15 2016 aloisio@gmx.com
- Update to version 2.1.1
  * Add `~` to episode/season separators.
  * Add `AHDTV`, `HDTC`, `SATRip` as new `format` possible
    values.
  * Add `streaming_service` property.
  * Add `DDP` pattern as `audio_codec`=`DolbyDigital`.
  * Add `LDTV` as possible tag for `other`=`LD`.
  * Add `StripSeparators` Post Processor to strip separators
    from all matches.
  * Fix invalid guess `1 x 2` with `--type episode`.
  * Fix `part` property.
  * Fix `cd_count` issue with `x264-CD`.
  * Fix `HDD` group detected as `DolbyDigital`.
  * Fix invalid comparator in `audio_codec` conflict solver.
  * Fix validation of `film` property.
  * Fix `date` followed by `screen_size` invalid guess.
  * Fix `episode` not detected when smaller filepart repeats the
    `season` and uses `SSEE` pattern.
  * Enhance `season`/`episode` conflict solver to keep most
    specific value.
  * Enhance `video_profile` detection.
  * Enhance `episode`/`season` range and sequence guessing.
  * Enhance performance with rebulk upgrade to `0.8.2`.
  * Enhance `season`/`episode`.
  * Enhance `other`=`Complete` guessing.
  * Enhance `release_group` guessing.
  * Enhance command line options parsing related to unicode.
  * Ensure roman numbers are surrounded with separators to be
    guessed as numbers.
* Fri Sep  9 2016 aloisio@gmx.com
- Update to version 2.1.0
  * Drop support for `regex` native module.
  * Remove dependency constraint on `python-dateutil`.
  * Enhance langage/country guessing in edge cases.
  * Enhance rule to guess `release_group` in more file
    templates.
  * Fix edge cases for subtitle language detection.
  * Fix invalid conflict solving in `season`/`episode`
    occuring between `SssEee` and `ssXee` pattern.
  * Fix issue when running guessit in non-interactive shell
    with python 2
  * Guess Dolby keyword as DolbyDigital in `audio_codec`.
  * Avoid `title` to be guessed as `website` (Dark.Net)
  * Avoid `season`/`episode` to be guessed when pattern is
    included inside words.
  * Enhance `screen_size` to detect `720pHD` and `1080pHD`
  * Add support for `format` and `video_codec` when no
    separators between themselves. (HDTVx264, PDTVx264, ...)
  * Add rebulk version in `--version` option.
  * Upgrade rebulk to `0.7.3`.
* Mon Apr 25 2016 aloisio@gmx.com
- Update to version 2.0.5
  * Fix inconsistent properties returned by guessit -p.
  * Add support for titles containing dots.
  * Lock python-dateutil dependency to <2.5.2.
  * Add an Exception Report when an unexpected exception occurs.
  * Fix possible issue with unicode characters encoding/decoding.
  * Add support for any type of string with python 2 and python 3
    (binary, str, unicode).
  * Remove regex native module from required dependencies.
    It will now be used only if present.
  * Guessit is now available as a docker container on Docker Hub
    (https://hub.docker.com/r/toilal/guessit).
  * `country` 2-letter code is not added to `title` value anymore.
  * All `container` values are now capitalized.
  * `alternativeTitle` has been renamed to `alternative_title`
    and added to the docs.
  * `mimetype` property is now in the docs.
  * Add more excluded words for `language` property.
  * Add more possible values for `other` property.
  * Fix an issue occuring with `title` values starting with `Scr`.
  * `film` property is now guessed only if less than `100` to
    avoid possible conflicts with `crc32`.
  * Add docs.
  * Add exotic `screen_size` patterns support like `720hd`
    and `720p50`.
  * Rename `audio_codec` value `true-HD` to `trueHD`.
  * Add ``__version__`` to main module.
  * Single digit episodes are now guessed for ``--type episode``
    instead of ``--episode-prefer-number``.
  * Fix separators that could cause some titles to be splited
    with & and ;.
  * Avoid possible ``NoneType`` error.
  * Fallback to default title guessing when ``expected-title``
    is not found.
  * Add ``expected-group`` option.
  * Add validation rule for single digit ``episode`` to avoid
    false positives.
  * Add ``verbose`` option.
  * Fix ``expected-title`` option.
  * Better unicode support in ``expected-group``/``expected-title``
    option.
  * Add support for ``part`` with no space before number.
  * Avoid ``uuid`` and ``crc32`` collision with
    ``season``/``episode`` properties.
  * Add better space support for ``season``/``episode`` properties.
  * Ensure ``date`` property is found when conflicting with
    ``season``/``episode`` properties.
  * Fix ``IndexError`` when input has a closing group character
    with no opening one before.
  * Add ``--type`` option.
  * Add rebulk implicit option support.
  * Add python 2.6 support.
  * Enhance title guessing.
  * Upgrade rebulk to ``0.6.1``.
  * Rename ``properCount`` to ``proper_count``
  * Avoid crash when using ``-p``/``-V`` option with ``--yaml``
    and ``yaml`` module is not available.
  * Add ``-p``/``-V`` options to display properties and values
    that can be guessed.
  * Allow rebulk customization in API module.
  * Raise TypeError instead of AssertionError when non text
    is given to guessit API.
  * Rewrite from scratch using Rebulk.
- Added man page for guessit
* Sat Jul 18 2015 aloisio@gmx.com
- Update to version 0.10.3
  * Fix issues related to unicode encoding/decoding
  * Fix possible crashes in guess_video_rexps
  * Fix invalid guess result when crc32 contains 6 digits than
    can be parsed as a date
  version 0.10.2:
  * Use common words to resolve conflicts on strings
  * Bump babelfish version
  * Fix setuptools deprecation warning
  * Package argparse dependency only if python<2.7
* Wed Feb 11 2015 aloisio@gmx.com
- Initial version 1.0.1
